Expand several indicators results to PostgreSQL
Usage
expand_indi_psql(
agg,
agg_time,
anos,
indi = "all",
psql_table,
psql_schema,
psql_db,
psql_host,
psql_port,
psql_user = NULL,
psql_pwd = NULL
)Arguments
- agg
character vector. Spatial aggregation level.
uf_resfor UF of residence.uf_ocorfor UF of occurrence.regsaude_resfor regiao de saude of residence.regsaude_ocorfor regiao de saúde of occurence.mun_resfor municipality of residence.mun_ocorfor municipality of ocurrence.- agg_time
character vector. Time aggregation levels.
yearfor yearly data.monthfor monthly data.weekfor weekly data. Defaults toyear.- anos
numeric vector. Years
- indi
character function names vector. Defaults to
allfor all indi_ functions.- psql_table
character. Indicators table name.
- psql_schema
character. Schema name.
- psql_db
character. Database name.
- psql_host
character. psql server host address.
- psql_port
character. psql server port.
- psql_user
character. psql user name. If not provided, the function will look for it on renviron.
- psql_pwd
character. psql password. If not provided, the function will look for it on renviron.